.. include:: /_includes/wip_prolog.rst

:mod:`stix.common.related` Module
==================================

.. module:: stix.common.related

Classes
-------

.. autoclass:: GenericRelationship
	:show-inheritance:
	:members:

.. autoclass:: GenericRelationshipList
	:show-inheritance:
	:members:

.. autoclass:: RelatedPackageRef
	:show-inheritance:
	:members:

.. autoclass:: RelatedPackageRefs
	:show-inheritance:
	:members:

.. autoclass:: _BaseRelated
	:show-inheritance:
	:members:

.. autoclass:: RelatedCampaign
	:show-inheritance:
	:members:

.. autoclass:: RelatedCOA
	:show-inheritance:
	:members:

.. autoclass:: RelatedExploitTarget
	:show-inheritance:
	:members:

.. autoclass:: RelatedIdentity
	:show-inheritance:
	:members:

.. autoclass:: RelatedIncident
	:show-inheritance:
	:members:

.. autoclass:: RelatedIndicator
	:show-inheritance:
	:members:

.. autoclass:: RelatedObservable
	:show-inheritance:
	:members:

.. autoclass:: RelatedThreatActor
	:show-inheritance:
	:members:

.. autoclass:: RelatedTTP
	:show-inheritance:
	:members:
